import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'token.dart';
import 'error_codes.dart';

class StripePayment {
  static const MethodChannel _channel =
      const MethodChannel('stripe_basic_payment');

  /// https://tipsi.github.io/tipsi-stripe/docs/usage.html
  static void setOptions(StripeOptions settings) {
    _channel.invokeMethod('setOptions',
        {"options": settings.toJson(), "errorCodes": Errors.mapping});
  }

  /// https://tipsi.github.io/tipsi-stripe/docs/createTokenWithCard.html
  static Future<Token> createTokenWithCard(CreditCard card) async {
    final token =
        await _channel.invokeMethod("createTokenWithCard", card.toJson());
    return Token.fromJson(token);
  }

  /// https://tipsi.github.io/tipsi-stripe/docs/confirmSetupIntent.html
  static Future<Token> openBasicIntent(CreditCard card) async {
    final result =
        await _channel.invokeMethod('openBasicIntent', card.toJson());
    return Token.fromJson(result);
  }
}

class StripeOptions {
  final String publishableKey;
  final String merchantId;
  final String androidPayMode;

  StripeOptions(
      {@required this.publishableKey, this.merchantId, this.androidPayMode});

  factory StripeOptions.fromJson(Map<String, dynamic> json) {
    return StripeOptions(
        merchantId: json['merchantId'],
        publishableKey: json['publishableKey'],
        androidPayMode: json['androidPayMode']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    if (this.merchantId != null) data['merchantId'] = this.merchantId;
    if (this.publishableKey != null)
      data['publishableKey'] = this.publishableKey;
    if (this.androidPayMode != null)
      data['androidPayMode'] = this.androidPayMode;
    return data;
  }
}
